@@ -32,8 +32,7 @@ def download_lib(lib_data: LibData, to_path: str):
     local_path = lib_data.gen_path()
     local_path = os.path.join(to_path, local_path)
     if os.path.exists(local_path):
-        print(f'{local_path} already exist.')
-        logger.info(f'{local_path} already exist.')
+        print(f'[warning] {local_path} already exist.')
         return
 
     zip_file = os.path.join(local_path, zip_name)
@@ -54,6 +53,9 @@ def parse_args():
     parser.add_argument('--dep', help='The dependencies json file in which the libs will be download from lib repo')
     parser.add_argument('--dest', help='Where download the libs to')
 
+    sub_parsers = parser.add_subparsers(dest='sub_command')
+    list_parser = sub_parsers.add_parser('list')
+
     return parser.parse_args()
 
 
@@ -79,9 +81,16 @@ def try_find_compatible_libs(repo: LibRepo, name: str, ver: str, platform: str,
     return libs
 
 
+def list_command(args):
+    print(str(LibRepo().pull_repo()))
+
+
 def lib_get():
     args = parse_args()
 
+    if args.sub_command == 'list':
+        return list_command(args)
+
     def strip(s):
         return s.strip() if s else None
 
@@ -111,7 +120,7 @@ def lib_get():
         if compatible_libs:
             libs.extend(compatible_libs)
         else:
-            logger.error(f'can not find lib from repo. name: {name}, version: {ver}, platform: {platform}, architecture: {arch}, build: {build}')
+            print(f'[error] can not find lib from repo. name: {name}, version: {ver}, platform: {platform}, architecture: {arch}, build: {build}')
 
     for lib in libs:
         download_lib(lib, args.dest)
